ytree\.tree\_farm\.ancestry\_checker\.AncestryChecker
=====================================================

.. currentmodule:: ytree.tree_farm.ancestry_checker

.. autoclass:: AncestryChecker

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AncestryChecker.__init__
   
   

   
   
   